summaryrefslogtreecommitdiff
path: root/includes/content/Content.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/content/Content.php')
-rw-r--r--includes/content/Content.php7
1 files changed, 5 insertions, 2 deletions
diff --git a/includes/content/Content.php b/includes/content/Content.php
index 61b9254f..8ed761f5 100644
--- a/includes/content/Content.php
+++ b/includes/content/Content.php
@@ -292,6 +292,9 @@ interface Content {
* Subclasses may implement this to determine the necessary updates more
* efficiently, or make use of information about the old content.
*
+ * @note Implementations should call the SecondaryDataUpdates hook, like
+ * AbstractContent does.
+ *
* @param Title $title The context for determining the necessary updates
* @param Content $old An optional Content object representing the
* previous content, i.e. the content being replaced by this Content
@@ -461,7 +464,7 @@ interface Content {
*
* @param WikiPage $page The page to be saved.
* @param int $flags Bitfield for use with EDIT_XXX constants, see WikiPage::doEditContent()
* @param int $baseRevId The ID of the current revision
* @param User $user
*
* @return Status A status object indicating whether the content was
@@ -470,7 +473,7 @@ interface Content {
*
* @see WikiPage::doEditContent()
*/
- public function prepareSave( WikiPage $page, $flags, $baseRevId, User $user );
+ public function prepareSave( WikiPage $page, $flags, $parentRevId, User $user );
/**
* Returns a list of updates to perform when this content is deleted.
@@ -461,7 +464,7 @@ interface Content {
* @param WikiPage $page The page to be saved.
* @param int $flags Bitfield for use with EDIT_XXX constants, see WikiPage::doEditContent()
- * @param int $baseRevId The ID of the current revision
+ * @param int $parentRevId The ID of the current revision
* @param User $user
*